( cd usr/bin ; rm -rf tcat )
( cd usr/bin ; ln -sf toast tcat )
( cd usr/bin ; rm -rf untoast )
( cd usr/bin ; ln -sf toast untoast )
( cd usr/lib ; rm -rf libgsm.so )
( cd usr/lib ; ln -sf libgsm.so.1.0.10 libgsm.so )
( cd usr/lib ; rm -rf libgsm.so.1 )
( cd usr/lib ; ln -sf libgsm.so.1.0.10 libgsm.so.1 )
